@@ -6,37 +6,30 @@ import json
 
 import pytest
 
-from dateutil import parser
+from datetime import datetime
 
 
 @pytest.mark.parametrize(
-    "createdSince, createdBefore, limit, expected_number",
+    "limit, expected_number",
     [
-        ("01-01-2018", None, None, 1),
-        (None, "01-01-2018", None, 2),
-        (None, "01-01-2015", None, 0),
-        (None, None, 1, 1),
-        (None, None, None, 3),
+        (None, 3),
+        (2, 2),
     ],
 )
-def test_get_jobs(createdSince, createdBefore, limit, expected_number, auth_client):
+def test_get_jobs(limit, expected_number, auth_client):
     """Tests get method for api/jobs with various query strings"""
 
     auth_client = auth_client[0]
 
     query_string = "api/jobs"
 
-    if createdSince is not None:
-        query_string += f"?createdSince={createdSince}"
-    if createdBefore is not None:
-        query_string += f"?createdBefore={createdBefore}"
     if limit is not None:
         query_string += f"?limit={limit}"
 
     response = auth_client.get(query_string)
     jobs_received = response.json
 
-    assert len(jobs_received) == expected_number
+    assert len(jobs_received) == expected_number, jobs_received
 
 
 def test_get_job_by_id(auth_client):
@@ -45,21 +38,19 @@ def test_get_job_by_id(auth_client):
 
     response = auth_client.get("api/jobs/3")
 
+    sub_time = datetime.fromisoformat("2016-08-29T09:12:00.000000+00:00").astimezone()
+    sub_time = sub_time.strftime(format="%Y-%m-%d %H:%M")
     expected_response = {
         "flowchart_id": "ABCD",
         "id": 3,
         "path": "/Users/username/seamm/projects",
-        "submitted": parser.parse("2019-08-29T09:12:33.001000+00:00").replace(
-            tzinfo=None
-        ),
+        "submitted": sub_time,
     }
 
     received = response.json
 
     for k in expected_response.keys():
         if k == "submitted":
-            received[k] = parser.parse(received[k])
-
             assert received[k] == expected_response[k]
 
     assert response.status_code == 200
@@ -82,7 +73,7 @@ def test_get_flowchart_logged_in(auth_client):
 
     auth_client = auth_client[0]
 
-    response = auth_client.get("api/flowcharts/ABCD")
+    response = auth_client.get("api/flowcharts/100")
 
     assert response.status_code == 200
 
@@ -93,7 +84,7 @@ def test_get_cytoscape_logged_in(auth_client):
     """
     auth_client = auth_client[0]
 
-    response = auth_client.get("api/flowcharts/ABCD/cytoscape")
+    response = auth_client.get("api/flowcharts/100/cytoscape")
     assert response.status_code == 201
 
 
@@ -149,7 +140,7 @@ def test_get_project(auth_client):
 
     auth_client = auth_client[0]
 
-    response = auth_client.get("api/projects/2")
+    response = auth_client.get("api/projects/100")
 
     assert response.status_code == 200
 
@@ -159,7 +150,7 @@ def test_get_project_jobs(auth_client):
 
     auth_client = auth_client[0]
 
-    response = auth_client.get("api/projects/2/jobs")
+    response = auth_client.get("api/projects/100/jobs")
 
     assert response.status_code == 200
 
@@ -169,6 +160,6 @@ def test_get_project_jobs_404(auth_client):
 
     auth_client = auth_client[0]
 
-    response = auth_client.get("api/projects/100/jobs")
+    response = auth_client.get("api/projects/1000/jobs")
 
     assert response.status_code == 404
